@@ -6,7 +6,7 @@ use Carp ();
 use HTTP::Date qw(str2time);
 use base qw( Exporter );
 
-our $VERSION = '6.06_01';
+our $VERSION = '6.08_01';
 $VERSION =~ tr/_//d;
 sub Version { $VERSION; }
 
@@ -131,12 +131,10 @@ package File::Listing::unix;
 
 use HTTP::Date qw(str2time);
 
+our @ISA = qw(File::Listing);
+
 # A place to remember current directory from last line parsed.
-use vars qw($curdir @ISA);
-
-@ISA = qw(File::Listing);
-
-
+our $curdir;
 
 sub init
 {
@@ -226,10 +224,10 @@ package File::Listing::dosftp;
 
 use HTTP::Date qw(str2time);
 
-# A place to remember current directory from last line parsed.
-use vars qw($curdir @ISA);
+our @ISA = qw(File::Listing);
 
-@ISA = qw(File::Listing);
+# A place to remember current directory from last line parsed.
+our $curdir;
 
 
 
@@ -293,9 +291,7 @@ package File::Listing::netware;
 
 package File::Listing::apache;
 
-use vars qw(@ISA);
-
-@ISA = qw(File::Listing);
+our @ISA = qw(File::Listing);
 
 
 sub init { }
@@ -330,7 +326,7 @@ sub line {
 	$filesize = int $filesize;
 
 	require Time::Local;
-	my $filetime = Time::Local::timelocal(0,$M,$H,$d,$m-1,_guess_year($y)-1900);
+	my $filetime = Time::Local::timelocal(0,$M,$H,$d,$m-1,_guess_year($y));
 	my $filetype = ($filename =~ s|/$|| ? "d" : "f");
 	return [$filename, $filetype, $filesize, $filetime, undef];
     }
@@ -341,9 +337,21 @@ sub line {
 
 sub _guess_year {
     my $y = shift;
-    if ($y >= 90) {
+
+    # if the year is already four digit then we shouldn't do
+    # anything to modify it.
+    if ($y >= 1900) {
+        # do nothing
+
+    # TODO: for hysterical er historical reasons we assume 9x is in the
+    # 1990s we should probably not do that, but I don't have any examples
+    # where apache provides two digit dates so I am leaving this as-is
+    # for now.  Possibly the right thing is to not handle two digit years.
+    } elsif ($y >= 90) {
 	$y = 1900+$y;
     }
+
+    # TODO: likewise assuming 00-89 are 20xx is long term probably wrong.
     elsif ($y < 100) {
 	$y = 2000+$y;
     }
@@ -375,25 +383,25 @@ __END__
 
 =head1 NAME
 
-File::Listing - parse directory listing
+File::Listing - Parse directory listing
 
 =head1 SYNOPSIS
 
  use File::Listing qw(parse_dir);
  $ENV{LANG} = "C";  # dates in non-English locales not supported
- for (parse_dir(`ls -l`)) {
-     ($name, $type, $size, $mtime, $mode) = @$_;
+ foreach my $file (parse_dir(`ls -l`)) {
+     ($name, $type, $size, $mtime, $mode) = @$file;
      next if $type ne 'f'; # plain file
      #...
  }
  
  # directory listing can also be read from a file
- open(LISTING, "zcat ls-lR.gz|");
- $dir = parse_dir(\*LISTING, '+0000');
+ open my $listing, "zcat ls-lR.gz|";
+ $dir = parse_dir($listing, '+0000');
 
 =head1 DESCRIPTION
 
-This module exports a single function called parse_dir(), which can be
+This module exports a single function called C<parse_dir>, which can be
 used to parse directory listings.
 
 =head1 FUNCTIONS
@@ -418,9 +426,9 @@ parsing time stamps in the listing. If this value is undefined,
 then the local time zone is assumed.
 
 The third parameter (C<$type>) is the type of listing to assume.
-Currently supported formats are 'unix', 'apache' and 'dosftp'.
-The default value is 'unix'.  Ideally, the listing type should
-be determined automatically.
+Currently supported formats are C<'unix'>, C<'apache'> and
+C<'dosftp'>. The default value is C<'unix'>. Ideally, the listing
+type should be determined automatically.
 
 The fourth parameter (C<$error>) specifies how unparseable lines
 should be treated. Values can be C<'ignore'>, C<'warn'> or a code reference.
@@ -470,6 +478,16 @@ Bitmask a la the mode returned by C<stat>.
 
 =back
 
+=head1 SEE ALSO
+
+=over 4
+
+=item L<File::Listing::Ftpcopy>
+
+Provides the same interface but uses XS and the parser implementation from C<ftpcopy>.
+
+=back
+
 =head1 COPYRIGHT
 
 Copyright 1996-2010, Gisle Aas
